document.addEventListener('DOMContentLoaded', () => {
  const searchInput = document.getElementById('searchInput');
  const specializationFilter = document.getElementById('specializationFilter');
  const grid = document.getElementById('researcherGrid');

  // Create researcher cards from table data
  const table = document.querySelector('table');
  const researchers = Array.from(table.querySelectorAll('tr')).slice(1)
    .map(row => {
      const cells = row.querySelectorAll('td');
      return {
        name: cells[1].textContent,
        institution: cells[2].textContent,
        specialization: cells[3].textContent,
        hIndex: cells[4].textContent,
        citations: cells[5].textContent,
        activeYears: cells[6].textContent
      };
    });

  function createResearcherCard(researcher) {
    return `
      <div class="researcher-card">
        <h3 class="researcher-name">${researcher.name}</h3>
        <div class="researcher-stats">
          <div><span class="stat-label">Institution:</span> ${researcher.institution}</div>
          <div><span class="stat-label">Specialization:</span> ${researcher.specialization}</div>
          <div><span class="stat-label">h-index:</span> ${researcher.hIndex}</div>
          <div><span class="stat-label">Citations:</span> ${researcher.citations}</div>
          <div><span class="stat-label">Active Years:</span> ${researcher.activeYears}</div>
        </div>
      </div>
    `;
  }

  function updateDisplay() {
    const searchTerm = searchInput.value.toLowerCase();
    const specializationTerm = specializationFilter.value.toLowerCase();
    
    const filtered = researchers.filter(r => {
      const matchesSearch = Object.values(r).some(val => 
        val.toString().toLowerCase().includes(searchTerm)
      );
      const matchesSpecialization = specializationTerm === '' || 
        r.specialization.toLowerCase().includes(specializationTerm);
      return matchesSearch && matchesSpecialization;
    });

    grid.innerHTML = filtered.map(createResearcherCard).join('');
  }

  searchInput.addEventListener('input', updateDisplay);
  specializationFilter.addEventListener('change', updateDisplay);

  // Hide the original table
  table.style.display = 'none';
  
  // Initial display
  updateDisplay();
});
